aboutsummaryrefslogtreecommitdiff
path: root/src/libjin/Input/je_mouse.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/libjin/Input/je_mouse.h')
-rw-r--r--src/libjin/Input/je_mouse.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/libjin/Input/je_mouse.h b/src/libjin/Input/je_mouse.h
index f229ed1..6f01993 100644
--- a/src/libjin/Input/je_mouse.h
+++ b/src/libjin/Input/je_mouse.h
@@ -5,9 +5,9 @@
#include "../common/je_singleton.hpp"
-namespace jin
+namespace JinEngine
{
- namespace input
+ namespace Input
{
class Mouse : public Singleton<Mouse>
@@ -24,8 +24,8 @@ namespace jin
};
- } // namespace input
-} // namespace jin
+ } // namespace Input
+} // namespace JinEngine
#endif // LIBJIN_MODULES_INPUT
#endif // __JE_MOUSE_H \ No newline at end of file